<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\Sm00003000ParamFatEscopoService;

class Sm00003000ParamFatEscopoController extends SMCrud
{
    protected $dataSourceName = "fct_paramfatescopo_widget";
    protected $newCode;
    protected $paramescservice;

    public function __construct ($crudService, $environment, NewCode $newCode, Sm00003000ParamFatEscopoService $paramescservice) {
        parent::__construct($crudService, $environment);
        $this->newCode         = $newCode;
        $this->paramescservice = $paramescservice;
    }
    
    public function save(Request $request, Response $response) {
        $rows  = $request->getDataSet()->getRows();
        $nrorg = $this->environment->getNrOrg();
        foreach($rows as $row) {
            if ($row["__is_new"])
                $row["NRSEQFATUESCOPO"] = $this->newCode->getCodeByTableName("FCT_PARAMFATESCOPO", $nrorg, 1, 10, true);
        }
        
        parent::save($request, $response);
    }
    
    public function validarParamsFaturamentoEscopo(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $nrorg           = $this->environment->getNrOrg();
            
            $result = $this->paramescservice->validarParamsFaturamentoEscopo($nrtipoorcamento, $nrorg);
            $response->addDataSet(new DataSet("fct_tipoorcamento_widget", array("ESCOPOSINVALIDOS" => $result)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    
    /**
     * A função "completaPercentual" verifica qual o percentual faltante para inserção na página "índices Financeiros Padrões"
     */
    
    public function completaPercentual(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrorg = $this->environment->getNrOrg();
            $nrtipoorcamento = $row['NRTIPOORCAMENTO'];
    
            $result = $this->paramescservice->completaPercentual($nrtipoorcamento, $nrorg);
            
            $response->addDataSet(new DataSet("completaPercentual", array("PERCENTUAL" => $result)));

        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * A função "validaPercentual" valida o percentual para inserção na página "índices Financeiros Padrões"
     */
    
    public function validaPercentual(Request\Row $request, Response $response) {
        try{
            $row = $request->getRow();
            
            $nrorg = $this->environment->getNrOrg();
            $nrtipoorcamento = $row['NRTIPOORCAMENTO'];
            $nrpercentindice = $row['NRPERCENTINDICE'];
            $cdindice        = $row["CDINDICE"];
    
            $result = $this->paramescservice->validaPercentual($nrtipoorcamento, $nrpercentindice, $nrorg, $cdindice);
            
            $response->addDataSet(new DataSet("validaPercentual", array("PERCENTUAL" => $result)));

        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Retorna o valor do campo "Tipo de cálculo para parcelas incompletas"
     */
    public function getTipoCalculoPeriodosIncompletos(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nrtipoorcamento = $row["NRTIPOORCAMENTO"];
            $nrorg           = $this->environment->getNrOrg();
            
            $idtpcalcparcinc = $this->paramescservice->getTipoCalculoPeriodosIncompletos($nrtipoorcamento, $nrorg);
            $response->addDataSet(new DataSet("retorno", array("IDTPCALCPARCINC" => $idtpcalcparcinc)));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}
?>