<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\Sm00024000ParametrizacaoResultadoContratoProdutoService as parametrizacaoProdutoService ;


class Sm00024000ParametrizacaoResultadoContratoProdutoController extends SMCrud {
    
    protected $dataSourceName = "fct_elementoproddesp";
    protected $newCode;
    protected $parametrizacaoProdutoService;
    
    public function __construct($crudService, $environment, NewCode $newCode, parametrizacaoProdutoService $parametrizacaoProdutoService) {
        parent::__construct($crudService, $environment);
        $this->newCode = $newCode;
        $this->parametrizacaoProdutoService = $parametrizacaoProdutoService;
    }
   

   /**
    *  Função que salva um registro de parametros de Produto pelo crud
    */

    public function save(Request $request, Response $response){
        try {
            $nrorg = $this->environment->getNrOrg();
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                
              $row["NRELEMENTOPRODDESP"] = $this->newCode->getCodeByTableName("FCT_ELEMENTOPRODDESP", $nrorg, 1, 10, true);
            }
            unset($row);
            
            parent::save($request, $response);
            
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    /**
     *  A função "validar" que verifica se já existe produto para o elemento Selecionado 
     *  que está salvo na widget de Produtos.
     */
     
    public function validar(Request $request, Response $response){
        try {
            $row = $request->getRow();
            $cdservorca = $row["CDSERVORCA"];
            $cdproduto = $row["CDPRODUTO"]; 
            $nrorg = $this->environment->getNrOrg();
            
            $resultado = $this->parametrizacaoProdutoService->validar($cdservorca, $cdproduto, $nrorg);
            
            $response->addDataSet(
                new DataSet(
                    "validar", array(
                        "resultado" => $resultado
                    )
                )
            );
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    
}

?>

