<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00004000DocumentoContratoFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Retorna os documentos do contrato.
     */
    public function getDocumentosContrato(array $params) {
        $sql = "SELECT NRSEQCONTDOC,
                       NMARQUIVO,
                       DSCAMINHOARQ,
                       TXMODELODOCORCA,
                       DSTIPO,
                       IDSITUACAOCONTRATO,
                       VRTAMANHOLOGO
                  FROM FCT_CONTRATODOC
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG
                   AND ((IDSITUACAOCONTRATO = :IDSITUACAOCONTRATO)
                         OR (IDSITUACAOCONTRATO IS NULL))";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os documentos de rescisão do contrato.
     */
    public function getDocumentosRescisao(array $params) {
        $sql = "SELECT FCT_MODELODOC.NRSEQMODDOCFCT,
                       FCT_MODELODOC.NMARQUIVO,
                       FCT_MODELODOC.DSCAMINHOARQ,
                       FCT_MODELODOC.TXMODELODOCORCA,
                       FCT_MODELODOC.DSTIPO,
                       FCT_CONTRATO.IDSITUACAOCONTRATO,
                       FCT_MODELODOC.VRTAMANHOLOGO
                  FROM FCT_MODELODOC
                  JOIN FCT_TIPORESCISAO 
                    ON FCT_TIPORESCISAO.NRSEQMODDOCFCT = FCT_MODELODOC.NRSEQMODDOCFCT
                   AND FCT_TIPORESCISAO.NRORG = FCT_MODELODOC.NRORG
                  JOIN FCT_CONTRATO 
                    ON FCT_CONTRATO.NRTIPORESCISAO = FCT_TIPORESCISAO.NRTIPORESCISAO
                   AND FCT_CONTRATO.NRORG = FCT_TIPORESCISAO.NRORG 
                 WHERE FCT_CONTRATO.NRSEQCONTRATO  = :NRSEQCONTRATO
                   AND FCT_CONTRATO.NRTIPORESCISAO = :NRTIPORESCISAO
                   AND FCT_CONTRATO.NRORG          = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os dados principais do contrato
     */
    public function getDadosContrato(array $params) {
        $sql = "SELECT CT.NRCONTRATOFCT,
                       TO_CHAR(NVL(CT.DTINIVIGENCONT, CT.DTINICIOCONTRATO), 'DD/MM/YYYY') AS DTINICIOCONTRATO,
                       TO_CHAR(NVL(CT.DTFINVIGENCONT, CT.DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFIMCONTRATO,
                       CT.NRDIASPRAZOCONT,
                       CT.NRPARCNEGOCIO,
                       CT.CDINDFINCONT,
                       TO_CHAR(CT.DTPADREAJCONT, 'DD/MM/YYYY') AS DTPADREAJCONT,
                       CT.QTPOSTOTRABCONT,
                       TO_CHAR(CT.DTPADRPRORGCONT, 'DD/MM/YYYY') AS DTPADRPRORGCONT,
                       CT.CDFILIALORCA,
                       OC.CDMODPGTO,
                       MODPGTO.DSMODPGTO,
                       OC.NRPARCINTERLOCUTOR,
                       INTER.NMPRINCIPALPARC AS NMPARCINTERLOCUTOR,
                       CT.DSREFERENCIACONT,
                       CT.DSOBSERVACAOCONT,
                       OPER.NMOPERADOR AS NMOPERRESPONSAVEL,
                       CEIL(MONTHS_BETWEEN(NVL(CT.DTFINVIGENCONT, CT.DTFIMCONTRATO), NVL(CT.DTINIVIGENCONT, CT.DTINICIOCONTRATO))) AS PRAZOMES,
                       (SELECT NVL(SUM(VRRECUCONT), 0)
                          FROM FCT_RECURSOSCONTR
                         WHERE NRSEQCONTRATO = CT.NRSEQCONTRATO
                           AND IDRECURATIV   = 'S'
                           AND NRORG         = CT.NRORG) AS VRRECUCONT
                  FROM FCT_CONTRATO CT
                  LEFT JOIN FCT_REFEORCACONT RF
                    ON CT.NRSEQCONTRATO = RF.NRSEQCONTRATO
                   AND CT.NRORG         = RF.NRORG
                  LEFT JOIN FCT_ORCAMENTO OC
                    ON RF.NRSEQORCAMENTO = OC.NRSEQORCAMENTO
                   AND RF.NRORG          = OC.NRORG
                  LEFT JOIN MODPGTO
                    ON OC.CDMODPGTO = MODPGTO.CDMODPGTO
                   AND OC.NRORG     = MODPGTO.NRORG
                  LEFT JOIN PARCNEGOCIO INTER
                    ON OC.NRPARCINTERLOCUTOR = INTER.NRPARCNEGOCIO
                   AND OC.NRORG              = INTER.NRORG
                  LEFT JOIN OPERADOR OPER
                    ON CT.CDOPERRESPONSAVEL = OPER.CDOPERADOR
                   AND CT.NRORG             = OPER.NRORG
                 WHERE CT.NRORG         = :NRORG
                   AND CT.NRSEQCONTRATO = :NRSEQCONTRATO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getNotaExp(array $params) {
        $sql = "SELECT MAX(NF.NRNOTAFISC) AS NRNOTAFISC
                  FROM FCT_RECURSOSCONTR REC
                 INNER JOIN ITEMPRODUTO IPD
                    ON REC.NRPEDIDO  = IPD.NRPEDIDO
                   AND REC.NRITEMPED = IPD.NRITEMPED
                   AND REC.NRORG     = IPD.NRORG
                 INNER JOIN NOTAFISCAL NF
                    ON IPD.CDFILIAL   = NF.CDFILIAL
                   AND IPD.NRLANCTONF = NF.NRLANCTONF
                   AND IPD.NRORG      = NF.NRORG
                 WHERE REC.NRORG         = :NRORG
                   AND REC.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NF.NRNOTAFISC     IS NOT NULL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Busca os dados do comprador do contrato.
     */
    public function getDadosCompradorContrato(array $params) {
        $sql = "SELECT DISTINCT PARC.NRINSCRICAOPARC,
                       PARC.NMPRINCIPALPARC,
                       CLI.NRINSESTCLIE
                  FROM PARCNEGOCIO PARC
                  LEFT JOIN CLIENTE CLI
                    ON PARC.NRPARCNEGOCIO = CLI.NRPARCNEGOCIO
                   AND PARC.NRORG         = CLI.NRORG
                 WHERE PARC.NRPARCNEGOCIO  = :NRPARCNEGOCIO
                   AND PARC.NRORG          = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna o endereço de um determinado tipo do parceiro de negócio informado.
     */
    public function getEnderecoParceiro(array $params) {
        $sql = "SELECT DISTINCT (ENDE.DSENDERECO || DECODE(ENDE.NRIMOVELENDERECO, NULL, '', ' ' || ENDE.NRIMOVELENDERECO) || DECODE(ENDE.DSCOMPLEENDERECO, NULL, '', ', ' || ENDE.DSCOMPLEENDERECO) || ' - ' || NVL(BAIRRO.NMBAIRRO, ENDE.NMBAIRROENDERECO) || ', ' || MUN.NMMUNICIPIO || ' - ' || ENDE.SGESTADO) AS ENDERECO,
                       ENDE.DSENDERECO,
                       MUN.NMMUNICIPIO,
                       NVL(BAIRRO.NMBAIRRO, ENDE.NMBAIRROENDERECO) AS NMBAIRROENDERECO,
                       ENDE.SGESTADO,
                       EST.NMESTADO,
                       ENDE.NRCEPENDERECO
                  FROM ENDERECOPARC ENDE
                  LEFT JOIN ESTADO EST
                    ON ENDE.CDPAIS   = EST.CDPAIS
                   AND ENDE.SGESTADO = EST.SGESTADO
                  LEFT JOIN MUNICIPIO MUN
                    ON ENDE.CDMUNICIPIO = MUN.CDMUNICIPIO
                   AND ENDE.CDPAIS      = MUN.CDPAIS
                   AND ENDE.SGESTADO    = MUN.SGESTADO
                  LEFT JOIN BAIRRO
                    ON ENDE.CDBAIRRO     = BAIRRO.CDBAIRRO
                    AND ENDE.CDMUNICIPIO = BAIRRO.CDMUNICIPIO
                    AND ENDE.CDPAIS      = BAIRRO.CDPAIS
                    AND ENDE.SGESTADO    = BAIRRO.SGESTADO
                 WHERE ENDE.NRPARCNEGOCIO  = :NRPARCNEGOCIO
                   AND ENDE.NRORG          = :NRORG
                   AND ENDE.CDTIPOENDERECO = :CDTIPOENDERECO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna o endereço de entrega da proposta geradora do contrato.
     */
    public function getEnderecoEntregaProposta(array $params) {
        $sql = "SELECT DISTINCT (ENP.DSENDERECO || DECODE(ENP.NRIMOVELENDERECO, NULL, '', ' ' || ENP.NRIMOVELENDERECO) || DECODE(ENP.DSCOMPLEENDERECO, NULL, '', ', ' || ENP.DSCOMPLEENDERECO) || ' - ' || NVL(BAIRRO.NMBAIRRO, ENP.NMBAIRROENDERECO) || ', ' || MN.NMMUNICIPIO || ' - ' || ENP.SGESTADO) AS ENDERECO,
                       ENP.DSENDERECO,
                       MN.NMMUNICIPIO,
                       NVL(BAIRRO.NMBAIRRO, ENP.NMBAIRROENDERECO),
                       ENP.SGESTADO,
                       ENP.NRCEPENDERECO
                  FROM FCT_ENDERECOORCA ENP
                 INNER JOIN FCT_REFEORCACONT RF
                    ON RF.NRSEQORCAMENTO = ENP.NRSEQORCAMENTO
                   AND RF.NRORG          = ENP.NRORG
                  LEFT JOIN MUNICIPIO MN
                    ON ENP.CDMUNICIPIO = MN.CDMUNICIPIO
                   AND ENP.CDPAIS      = MN.CDPAIS
                   AND ENP.SGESTADO    = MN.SGESTADO
                 LEFT JOIN BAIRRO
                    ON ENP.CDBAIRRO     = BAIRRO.CDBAIRRO
                    AND ENP.CDMUNICIPIO = BAIRRO.CDMUNICIPIO
                    AND ENP.CDPAIS      = BAIRRO.CDPAIS
                    AND ENP.SGESTADO    = BAIRRO.SGESTADO
                 WHERE RF.NRSEQCONTRATO   = :NRSEQCONTRATO
                   AND RF.NRORG           = :NRORG
                   AND ENP.CDTIPOENDERECO = 'ENTREGA'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os dados do prestador do contrato.
     */
    public function getDadosPrestadorContrato(array $params) {
        $sql = "SELECT DISTINCT FI.NRINSJURFILI,
                       FI.NMRAZSOCFILI,
                       FI.CDINSCESTA,
                       (EDF.DSENDEFILI|| DECODE(EDF.DSCOMPENDFIL, NULL, '', ', ' || EDF.DSCOMPENDFIL) ||' - '||EDF.NMBAIRFILI||' - '||MN.NMMUNICIPIO||' - '||EDF.SGESTADO) AS ENDERECO,
                       EDF.DSENDEFILI,
                       MN.NMMUNICIPIO,
                       EDF.NMBAIRFILI,
                       EDF.SGESTADO,
                       NRCEPFILI
                  FROM FILIAL FI
                  LEFT JOIN ENDEFILI EDF
                    ON FI.CDFILIAL      = EDF.CDFILIAL
                   AND FI.NRORG         = EDF.NRORG
                   AND EDF.IDTPENDEFILI = 'P'
                  LEFT JOIN MUNICIPIO MN
                    ON EDF.CDMUNICIPIO = MN.CDMUNICIPIO
                   AND EDF.CDPAIS      = MN.CDPAIS
                   AND EDF.SGESTADO    = MN.SGESTADO
                 WHERE FI.CDFILIAL = :CDFILIAL
                   AND FI.NRORG    = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    public function getCodigoItensContrato(array $params) {
        $sql = "SELECT ROWNUM AS IND,
                       ITEM.*
                  FROM (
                        SELECT NRITEMOCONTRATO
                          FROM FCT_ITEMCONTRATO
                         WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                           AND NRORG          = :NRORG
                           AND IDITEMATIVO    = 'S'
                           AND IDADICITEMCONT = 'N'
                         ORDER BY NRITEMOCONTRATO
                       ) ITEM";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getCodigoItensAdicionaisContrato(array $params) {
        $sql = "SELECT ROWNUM AS IND,
                       ITEM.*
                  FROM (
                        SELECT NRITEMOCONTRATO
                          FROM FCT_ITEMCONTRATO
                         WHERE NRSEQCONTRATO     = :NRSEQCONTRATO
                           AND NRORG             = :NRORG
                           AND NRITEMCONTRATOPAI = :NRITEMOCONTRATO
                           AND IDITEMATIVO       = 'S'
                           AND IDADICITEMCONT    = 'S'
                         ORDER BY NRITEMOCONTRATO
                       ) ITEM";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getCodigoItensApuracaoFaturamentoContrato(array $params) {
        $sql = "SELECT ROWNUM AS IND,
                       ITEM.*
                  FROM (
                        SELECT NRITEMOCONTRATO
                          FROM FCT_ITEMCONTRATO
                         WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                           AND NRORG          = :NRORG
                           AND IDITEMATIVO    = 'S'
                           AND IDFATURACONTR  = 'A'
                           AND IDADICITEMCONT = 'N'
                         ORDER BY NRITEMOCONTRATO
                       ) ITEM";
                   
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getCodigoItensModalidadePagamentoContrato(array $params) {
        $sql = "SELECT ROWNUM AS IND,
                       ITEM.*
                  FROM (
                        SELECT NRITEMOCONTRATO
                          FROM FCT_ITEMCONTRATO
                         WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                           AND NRORG          = :NRORG
                           AND IDITEMATIVO    = 'S'
                           AND IDADICITEMCONT = 'N'
                           AND IDFATURACONTR  = 'O'
                         ORDER BY NRITEMOCONTRATO
                       ) ITEM";
                   
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getItensContrato(array $params) {
        $sql = "SELECT ROWNUM AS IND,
                       ITEM.*
                  FROM (
                        SELECT DECODE(IT.CDSERVORCA, NULL, IT.CDPRODUTO, IT.CDSERVORCA) AS CODITEM,
                               NVL(IT.QTITEMCONTRATO, 0) AS QTITEMCONTRATO,
                               IT.IDFATURACONTR,
                               IT.NRITEMOCONTRATO,
                               IT.NMITEMCONTRATO,
                               IT.IDMULTMEDVRTOT,
                               NVL(IT.QTMEDIDACONTR,0) AS QTMEDIDACONTR,
                               TM.DSTPMEDIDASERV,
                               IT.IDUNIDTEMPOSERV,
                               NVL(IT.QTTEMPOSERV, 0)   AS QTTEMPOSERV,
                               NVL(IT.VRUNITITEMCONT, 0) AS VRUNITITEMCONT,
                               NVL(IT.VRTOTITEMCONT, 0)  AS VRTOTITEMCONT,
                               NVL((IT.VRTOTITEMCONT), 0) TOTPERIODO,
                               NVL(LTRIM(TO_CHAR(IT.VRUNITITEMCONT,'999G999G999G990D99')),0) AS VRUNITITEMCONT2,
                               NVL(LTRIM(TO_CHAR(IT.VRTOTITEMCONT,'999G999G999G990D99')),0)  AS VRTOTITEMCONT2,
                               NVL((LTRIM(TO_CHAR(IT.VRTOTITEMCONT,'999G999G999G990D99'))),0) TOTPERIODO2,
                               MP.DSMODPGTO
                          FROM FCT_ITEMCONTRATO IT,
                               FCT_TIPOMEDIDASERV TM,
                               MODPGTO MP
                         WHERE IT.NRSEQCONTRATO     = :NRSEQCONTRATO
                           AND IT.NRORG             = :NRORG
                           AND IT.IDITEMATIVO       = 'S'
                           AND IT.IDADICITEMCONT    = 'N'
                           AND TM.CDTPMEDIDASERV(+) = IT.CDTPMEDIDASERV
                           AND TM.NRORG(+)          = IT.NRORG
                           AND MP.CDMODPGTO(+)      = IT.CDMODPGTO
                           AND MP.NRORG(+)          = IT.NRORG
                         ORDER BY IT.NRITEMOCONTRATO
                        ) ITEM";
                   
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getItensAdicionaisContrato(array $params) {
        $sql = "SELECT ROWNUM AS IND,
                       ITEM.*
                  FROM (
                        SELECT DECODE(IT.CDSERVORCA, NULL, IT.CDPRODUTO, IT.CDSERVORCA) AS CODITEM,
                               NVL(IT.QTITEMCONTRATO, 0) AS QTITEMCONTRATO,
                               IT.IDFATURACONTR,
                               IT.NRITEMOCONTRATO,
                               IT.NMITEMCONTRATO,
                               NVL(IT.QTMEDIDACONTR,0) AS QTMEDIDACONTR,
                               TM.DSTPMEDIDASERV,
                               IT.IDUNIDTEMPOSERV,
                               NVL(IT.QTTEMPOSERV, 0)   AS QTTEMPOSERV,
                               NVL(IT.VRUNITITEMCONT, 0) AS VRUNITITEMCONT,
                               NVL(IT.VRTOTITEMCONT, 0)  AS VRTOTITEMCONT,
                               NVL((IT.VRTOTITEMCONT), 0) TOTPERIODO,
                               NVL(LTRIM(TO_CHAR(IT.VRUNITITEMCONT,'999G999G999G990D99')),0) AS VRUNITITEMCONT2,
                               NVL(LTRIM(TO_CHAR(IT.VRTOTITEMCONT,'999G999G999G990D99')),0)  AS VRTOTITEMCONT2,
                               NVL((LTRIM(TO_CHAR(IT.VRTOTITEMCONT,'999G999G999G990D99'))),0) TOTPERIODO2,
                               MP.DSMODPGTO
                          FROM FCT_ITEMCONTRATO IT,
                               FCT_TIPOMEDIDASERV TM,
                               MODPGTO MP
                         WHERE IT.NRSEQCONTRATO     = :NRSEQCONTRATO
                           AND IT.NRORG             = :NRORG
                           AND IT.NRITEMCONTRATOPAI = :NRITEMCONTRATOPAI
                           AND IT.IDITEMATIVO       = 'S'
                           AND IT.IDADICITEMCONT    = 'S'
                           AND TM.CDTPMEDIDASERV(+) = IT.CDTPMEDIDASERV
                           AND TM.NRORG(+)          = IT.NRORG
                           AND MP.CDMODPGTO(+)      = IT.CDMODPGTO
                           AND MP.NRORG(+)          = IT.NRORG
                         ORDER BY IT.NRITEMOCONTRATO
                        ) ITEM";
                   
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getUrlFileServerLogotipoParceiro(array $params) {
        $sql = "SELECT DSDIRLOGOMARCA
                  FROM PARCNEGOCIO
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG         = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Busca a formaçẽos de preço do contrato
    **/
    public function getCodigoFormacaoPrecoContrato(array $params){
        $sql = "SELECT ROWNUM AS IND,
                    FORMACAO.*
                FROM (SELECT DISTINCT
                            FORMCONT.NRFORMPRECOSERVICO,
                            FORMPREC.NMFORMPRECOSERVICO,
                            FCT_REFEORCACONT.NRSEQORCAMENTO,
                            FCT_RELACFORMACAOPROP.NRITEMORCAMENTO,
                            FORMCONT.NRITEMOCONTRATO,
                            FORMCONT.NRSEQCONTRATO,
                            NMITEM.NMSERVORCA
                        FROM FCT_RELACFORMACAOCONT FORMCONT
                        INNER JOIN FCT_FORMPRECOSERVICO FORMPREC
                            ON FORMPREC.NRFORMPRECOSERVICO = FORMCONT.NRFORMPRECOSERVICO
                            AND FORMPREC.NRORG             = FORMCONT.NRORG
                        LEFT JOIN FCT_REFEORCACONT 
                            ON FORMCONT.NRSEQCONTRATO = FCT_REFEORCACONT.NRSEQCONTRATO
                            AND FORMCONT.NRORG        = FCT_REFEORCACONT.NRORG
                        LEFT JOIN FCT_RELACFORMACAOPROP 
                            ON FCT_RELACFORMACAOPROP.NRSEQORCAMENTO      = FCT_REFEORCACONT.NRSEQORCAMENTO
                            AND FCT_RELACFORMACAOPROP.NRORG              = FCT_REFEORCACONT.NRORG  
                            AND FCT_RELACFORMACAOPROP.NRFORMPRECOSERVICO = FORMPREC.NRFORMPRECOSERVICO
                        LEFT JOIN FCT_ITEMCONTRATO ITEM
                            ON FORMCONT.NRITEMOCONTRATO = ITEM.NRITEMOCONTRATO
                            AND FORMCONT.NRSEQCONTRATO  = ITEM.NRSEQCONTRATO
                            AND FORMCONT.NRORG          = ITEM.NRORG
                        LEFT JOIN FCT_SERVICOORCA NMITEM
                           ON  NMITEM.CDSERVORCA  = ITEM.CDSERVORCA
                           AND NMITEM.NRORG       = ITEM.NRORG 
                        WHERE FORMCONT.NRSEQCONTRATO = :NRSEQCONTRATO
                            AND FORMCONT.NRORG       = :NRORG) FORMACAO" ;
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna os itens de formação de preço do contrato
    **/
    public function getItensFormacaoPrecoContrato(array $params){
        $sql = "SELECT ROWNUM AS IND,
                       FORMACAO.*
                 FROM (SELECT DISTINCT LEVEL,
                              CALC.NRCALCFORMPRECSERV,
                              CALC.IDITEMCALCULO,
                              CALC.IDELEMENTO,
                              ELE.NMSERVORCA AS NMELEMENTO,
                              CALC.NRCALCFORMPRECSERVPAI,
                              CALC.VRPERCCALCULO,
                              CALC.VRUNITARIO,
                              CALC.QTCALCULO,
                              CALC.IDUSAMEDIDA,
                              CALC.QTMEDIDACALC,
                              CALC.VRTOTAL,
                              CALC.CDTPMEDIDASERV,
                              MED.DSTPMEDIDASERV,
                              (SELECT COUNT(*)
                                FROM FCT_CALCFORMPRECSERV
                                WHERE NRFORMPRECOSERVICO    = CALC.NRFORMPRECOSERVICO
                                  AND NRORG                 = CALC.NRORG
                                  AND NRCALCFORMPRECSERVPAI = CALC.NRCALCFORMPRECSERV) AS QTFILHOS
                         FROM FCT_CALCFORMPRECSERV CALC
                        INNER JOIN FCT_SERVICOORCA ELE
                          ON CALC.IDELEMENTO = ELE.IDELEMENTO
                          AND CALC.NRORG     = ELE.NRORG
                        LEFT JOIN FCT_TIPOMEDIDASERV MED
                            ON MED.CDTPMEDIDASERV  = CALC.CDTPMEDIDASERV
                            AND MED.NRORG          = CALC.NRORG 
                        WHERE CALC.NRFORMPRECOSERVICO = :NRFORMPRECOSERVICO
                          AND CALC.NRORG              = :NRORG
                        START WITH CALC.NRCALCFORMPRECSERV IN (SELECT NRCALCFORMPRECSERV
                                                                 FROM FCT_CALCFORMPRECSERV
                                                                WHERE NRFORMPRECOSERVICO     = :NRFORMPRECOSERVICO
                                                                  AND NRORG                  = :NRORG
                                                                  AND NRCALCFORMPRECSERVPAI IS NULL)
                       CONNECT BY PRIOR CALC.NRCALCFORMPRECSERV = CALC.NRCALCFORMPRECSERVPAI) FORMACAO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna as informações do itens das formações de preço alteradas
     * durante a inserção da proposta
    **/
    public function getItensFormacaoAuxiliarProposta(array $params){
        $sql = "SELECT ROWNUM AS IND,
                       FORMACAO.*
                 FROM (SELECT DISTINCT LEVEL,
                              CALC.NRCALCFORMPRECSERV,
                              CALC.IDITEMCALCULO,
                              CALC.IDELEMENTO,
                              ELE.NMSERVORCA AS NMELEMENTO,
                              CALC.NRCALCFORMPRECSERVPAI,
                              CALC.VRPERCCALCULO,
                              CALC.VRUNITARIO,
                              CALC.QTCALCULO,
                              CALC.IDUSAMEDIDA,
                              CALC.QTMEDIDACALC,
                              CALC.VRTOTAL,
                              CALC.CDTPMEDIDASERV,
                              MED.DSTPMEDIDASERV,
                              (SELECT COUNT(*)
                                FROM FCT_CALCFORMPRECSERV_ITPRO
                                WHERE NRFORMPRECOSERVICO    = CALC.NRFORMPRECOSERVICO
                                  AND NRORG                 = CALC.NRORG
                                  AND NRCALCFORMPRECSERVPAI = CALC.NRCALCFORMPRECSERV) AS QTFILHOS
                         FROM FCT_CALCFORMPRECSERV_ITPRO CALC
                        INNER JOIN FCT_SERVICOORCA ELE
                          ON CALC.IDELEMENTO = ELE.IDELEMENTO
                          AND CALC.NRORG     = ELE.NRORG
                        LEFT JOIN FCT_TIPOMEDIDASERV MED
                            ON MED.CDTPMEDIDASERV  = CALC.CDTPMEDIDASERV
                            AND MED.NRORG          = CALC.NRORG 
                        WHERE CALC.NRFORMPRECOSERVICO = :NRFORMPRECOSERVICO
                          AND CALC.NRORG              = :NRORG
                          AND CALC.NRSEQORCAMENTO     = :NRSEQORCAMENTO
                          AND CALC.NRITEMORCAMENTO    = :NRITEMORCAMENTO
                        START WITH CALC.NRCALCFORMPRECSERV IN (SELECT NRCALCFORMPRECSERV
                                                                 FROM FCT_CALCFORMPRECSERV_ITPRO
                                                                WHERE NRFORMPRECOSERVICO      = :NRFORMPRECOSERVICO
                                                                  AND NRSEQORCAMENTO          = :NRSEQORCAMENTO
                                                                  AND NRITEMORCAMENTO         = :NRITEMORCAMENTO
                                                                  AND NRORG                   = :NRORG
                                                                  AND NRCALCFORMPRECSERVPAI IS NULL)
                       CONNECT BY PRIOR CALC.NRCALCFORMPRECSERV = CALC.NRCALCFORMPRECSERVPAI) FORMACAO"; 
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna as informações do itens das formações de preço alteradas
     * durante a inserção da proposta
    **/
    public function getItensFormacaoAuxiliarContrato(array $params){
        $sql = "SELECT ROWNUM AS IND,
                   FORMACAO.*
                FROM (SELECT DISTINCT LEVEL,
                          CALC.NRCALCFORMPRECSERV,
                          CALC.IDITEMCALCULO,
                          CALC.IDELEMENTO,
                          ELE.NMSERVORCA AS NMELEMENTO,
                          CALC.NRCALCFORMPRECSERVPAI,
                          CALC.VRPERCCALCULO,
                          CALC.VRUNITARIO,
                          CALC.QTCALCULO,
                          CALC.IDUSAMEDIDA,
                          CALC.QTMEDIDACALC,
                          CALC.VRTOTAL,
                          CALC.CDTPMEDIDASERV,
                          MED.DSTPMEDIDASERV,
                          (SELECT COUNT(*)
                            FROM FCT_CALCFORMPRECSERV_ITCONT
                            WHERE NRFORMPRECOSERVICO    = CALC.NRFORMPRECOSERVICO
                              AND NRORG                 = CALC.NRORG
                              AND NRCALCFORMPRECSERVPAI = CALC.NRCALCFORMPRECSERV) AS QTFILHOS
                    FROM FCT_CALCFORMPRECSERV_ITCONT CALC
                    INNER JOIN FCT_SERVICOORCA ELE
                      ON CALC.IDELEMENTO = ELE.IDELEMENTO
                      AND CALC.NRORG     = ELE.NRORG
                    LEFT JOIN FCT_TIPOMEDIDASERV MED
                        ON MED.CDTPMEDIDASERV  = CALC.CDTPMEDIDASERV
                        AND MED.NRORG          = CALC.NRORG 
                    WHERE CALC.NRFORMPRECOSERVICO = :NRFORMPRECOSERVICO
                      AND CALC.NRORG              = :NRORG
                      AND CALC.NRSEQCONTRATO      = :NRSEQCONTRATO
                      AND CALC.NRITEMOCONTRATO    = :NRITEMOCONTRATO
                    START WITH CALC.NRCALCFORMPRECSERV IN (SELECT NRCALCFORMPRECSERV
                                                             FROM FCT_CALCFORMPRECSERV_ITCONT
                                                            WHERE NRFORMPRECOSERVICO      = :NRFORMPRECOSERVICO
                                                              AND NRSEQCONTRATO           = :NRSEQCONTRATO
                                                              AND NRITEMOCONTRATO         = :NRITEMOCONTRATO
                                                              AND NRORG                   = :NRORG
                                                              AND NRCALCFORMPRECSERVPAI IS NULL)
                   CONNECT BY PRIOR CALC.NRCALCFORMPRECSERV = CALC.NRCALCFORMPRECSERVPAI) FORMACAO"; 
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Substitui os dados de alteração contratual
     */
    public function getDadosAlteracaoContratual(array $params) {
        $sql = "SELECT DSALTERACONTRATUAIS
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
               
       $ps = $this->connection->prepare($sql);
       $ps->execute($params);
       return $ps->fetchAll();
    }
    
    /**
     * Retorna os dados de assinatura da proposta
     */
    public function getAssinaturasContrato(array $params) {
        $sql = "SELECT ROWNUM AS IND,
                       ASSINAT.*
                  FROM (SELECT
                            FCT_ASSINATDIGITALCONTR.NRASSDIGITALCONTR,
                            FCT_ASSINATDIGITALCONTR.NRSEQCONTRATO,
                            FCT_ASSINATDIGITALCONTR.NRPARCNEGOCIO,
                            FCT_ASSINATDIGITALCONTR.NRSEQINTERLOCUTOR,
                            DECODE(FCT_ASSINATDIGITALCONTR.NRPARCNEGOCIO, NULL, CRM_INTERLOCUTOR.NMINTERLOCUTOR, PARCNEGOCIO.NMPRINCIPALPARC) AS NMSIGNATARIO,
                            FCT_ASSINATDIGITALCONTR.NRCPFSIGNATARIO,
                            FCT_ASSINATDIGITALCONTR.IDTIPOASSINATURA,
                            FCT_ASSINATDIGITALCONTR.IDTESTEMUNHA,
                            FCT_ASSINATDIGITALCONTR.NRORDENACAO,
                            FCT_ASSINATDIGITALCONTR.IDSITUACAO,
                            FCT_ASSINATDIGITALCONTR.IDATIVO,
                            FCT_ASSINATDIGITALCONTR.NRORG
                        FROM
                            FCT_ASSINATDIGITALCONTR
                            LEFT JOIN PARCNEGOCIO ON FCT_ASSINATDIGITALCONTR.NRPARCNEGOCIO = PARCNEGOCIO.NRPARCNEGOCIO
                                  AND FCT_ASSINATDIGITALCONTR.NRORG = PARCNEGOCIO.NRORG
                            LEFT JOIN CRM_INTERLOCUTOR ON FCT_ASSINATDIGITALCONTR.NRSEQINTERLOCUTOR = CRM_INTERLOCUTOR.NRSEQINTERLOCUTOR
                                  AND FCT_ASSINATDIGITALCONTR.NRORG = CRM_INTERLOCUTOR.NRORG
                            JOIN FCT_CONTRATO ON FCT_ASSINATDIGITALCONTR.NRSEQCONTRATO = FCT_CONTRATO.NRSEQCONTRATO
                             AND FCT_ASSINATDIGITALCONTR.NRORG = FCT_CONTRATO.NRORG
                        WHERE FCT_ASSINATDIGITALCONTR.NRSEQCONTRATO = :NRSEQCONTRATO
                          AND FCT_ASSINATDIGITALCONTR.NRORG = :NRORG
                        ORDER BY
                            FCT_ASSINATDIGITALCONTR.NRORDENACAO,
                            PARCNEGOCIO.NMPRINCIPALPARC,
                            CRM_INTERLOCUTOR.NMINTERLOCUTOR) ASSINAT";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getcontratosRescindidos(array $params, $listaContratos) {
        $sql = "SELECT ROWNUM AS IND,
                       CONT.NRCONTRATOFCT,
                       CONT.DSREFERENCIACONT,
                       NVL(PROPOSTAFAS.NRPROPOSFAS, CONT.NRORCAMENTO) AS NRORCAMENTO
                  FROM (
                        SELECT FCT_CONTRATO.NRSEQCONTRATO,
                               FCT_CONTRATO.NRCONTRATOFCT,
                               FCT_CONTRATO.DSREFERENCIACONT,
                               FCT_ORCAMENTO.NRORCAMENTO
                          FROM FCT_CONTRATO
                          JOIN FCT_REFEORCACONT
                            ON FCT_REFEORCACONT.NRSEQCONTRATO = FCT_CONTRATO.NRSEQCONTRATO
                           AND FCT_REFEORCACONT.NRORG = FCT_CONTRATO.NRORG
                          JOIN FCT_ORCAMENTO
                            ON FCT_ORCAMENTO.NRSEQORCAMENTO = FCT_REFEORCACONT.NRSEQORCAMENTO
                           AND FCT_ORCAMENTO.NRORG = FCT_REFEORCACONT.NRORG
                         WHERE FCT_CONTRATO.NRSEQCONTRATO IN ($listaContratos)
                           AND FCT_CONTRATO.NRORG = :NRORG
                       ) CONT
                   LEFT JOIN (SELECT NRPROPOSFAS, NRSEQCONTRATO
                                FROM CONTRATOLINP
                               WHERE NRSEQCONTRATO IN ($listaContratos)
                                 AND NRPROPOSFAS <> '0000000261') PROPOSTAFAS
                     ON CONT.NRSEQCONTRATO = PROPOSTAFAS.NRSEQCONTRATO";
                   
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDadosRescisao(array $params) {
        $sql = "SELECT VRPENDENCIAFIN, 
                       TO_CHAR(DTRECISAOCONTR, 'DD/MM/YYYY') AS DTRECISAOCONTR, 
                       TO_CHAR(DTPEDRESCISAOCONTR, 'DD/MM/YYYY') AS DTPEDRESCISAOCONTR, 
                       DSJUSTIFICAENCERRA
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
                   
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
}

?>