<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00004003ReajusteContratoFactory
{
    protected $connection;
    
    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
    }
  
    /**
     * A função "recebeItensContrato" recebe os itens do Contrato
     */
    
    public function recebeItensContrato($params)
    {
        $sql = "SELECT NRITEMOCONTRATO, NRSEQCONTRATO, NMITEMCONTRATO, QTITEMCONTRATO, 
                       CDTPMEDIDASERV, QTMEDIDACONTR, IDMULTMEDVRTOT, VRUNITITEMCONT, 
                       VRTOTITEMCONT, IDTPDESCONTO, VRDESCONTO, NRORG
                  FROM FCT_ITEMCONTRATO
                 WHERE ((NRSEQCONTRATO = :NRSEQCONTRATO) OR (:NRSEQCONTRATO IS NULL))
                   AND ((NRITEMOCONTRATO = :NRITEMOCONTRATO) OR (:NRITEMOCONTRATO IS NULL))
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "gravarReajuste" insere o registro do reajuste.
     */
    public function gravarReajuste($params)
    {
        $sql = "INSERT INTO FCT_CONTRATOREAJUSTE 
                    (NRCONTREAJUSTE, NRSEQCONTRATO, NRITEMOCONTRATO, IDREAJUSTE, VRPERCREAJUSTE, CDTPINDICE,
                     IDPERVALOR, CDINDICE, VRPERCINDICE, VRTOTITANT, VRTOTITNOVO, VRPERCVARIACAOIT,
                     NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO,NRSEQPRORRCONT,NRULTIMOREAJUSTE)    
                VALUES
                    (:NRCONTREAJUSTE, :NRSEQCONTRATO, :NRITEMOCONTRATO, :IDREAJUSTE, :PERCENTUAL, :CDTPINDICE,
                     :IDPERVALOR, :CDINDICE, :PERCINDICE, ROUND(:VRTOTITEMCONT, 2), ROUND(:VRTOTAL, 2), :VRPERCVARIACAOIT,
                     :NRORG, SYSDATE, :NRORG, :CDOPERADOR, 'S',:NRSEQPRORRCONT, :NRULTIMOREAJUSTE)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Função públic usada para salvar dados relativos a um reajuste na tabela FCT_PRORROGCONTRATO.
    */
    public function gravarProrrogacaoContrato(array $params)
    {
        $sql = "INSERT INTO FCT_PRORROGCONTRATO
                ( NRSEQPRORRCONT, NRSEQCONTRATO, DTANTDTINICIAL, DTANDDTFINAL, CDOPERINCLUSAO, NRORG )
                VALUES
                (:NRSEQPRORRCONT, :NRSEQCONTRATO, :DTANTDTINICIAL, :DTANDDTFINAL, :CDOPERINCLUSAO, :NRORG )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    

    /**
    * A função "alteraItemContrato" altera os dados do item do contrato.
    */
    public function alteraItemContrato($params)
    {
        $sql = "UPDATE FCT_ITEMCONTRATO
                   SET VRUNITITEMCONT = ROUND(:VRUNITARIO, 2),
                       VRTOTITEMCONT  = ROUND(:VRTOTAL, 2),
                       DTULTATU = SYSDATE,
                       NRORGULTATU = :NRORG,
                       CDOPERULTATU = :CDOPERADOR
                 WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO
                   AND NRSEQCONTRATO =:NRSEQCONTRATO
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function getItensFilhosContrato(array $params)
    {
        $sql = "SELECT ITCONT.NRITEMOCONTRATO,
                       ITCONT.QTITEMCONTRATO,
                       ITCONT.QTMEDIDACONTR,
                       ITCONT.VRUNITITEMCONT,
                       ITCONT.VRTOTITEMCONT,
                       ITNEG.NRITNEGOCIACAOCONTRATO,
                       ITNEG.NRNEGOCIACAOCONTRATO
                  FROM FCT_ITEMCONTRATO ITCONT
                  LEFT JOIN FCT_ITNEGOCIACAOCONTRATO ITNEG
                    ON ITCONT.NRITEMOCONTRATO = ITNEG.NRITEMOCONTRATO
                   AND ITCONT.NRORG           = ITNEG.NRORG
                 WHERE ITCONT.NRSEQCONTRATO     = :NRSEQCONTRATO
                   AND ITCONT.NRORG             = :NRORG
                   AND ITCONT.NRITEMCONTRATOPAI IS NOT NULL
                   AND ITCONT.IDADICITEMCONT    = 'N'";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getItensPaiNegociacaoContrato(array $params)
    {
        $sql = "SELECT ITCONT.NRITEMOCONTRATO,
                       ITCONT.QTITEMCONTRATO,
                       ITCONT.QTMEDIDACONTR,
                       ITCONT.VRUNITITEMCONT,
                       ITCONT.VRTOTITEMCONT,
                       ITNEG.NRITNEGOCIACAOCONTRATO,
                       ITNEG.NRNEGOCIACAOCONTRATO
                  FROM FCT_ITEMCONTRATO ITCONT
                 INNER JOIN FCT_ITNEGOCIACAOCONTRATO ITNEG
                    ON ITCONT.NRITEMOCONTRATO = ITNEG.NRITEMOCONTRATO
                   AND ITCONT.NRORG           = ITNEG.NRORG
                 WHERE ITCONT.NRSEQCONTRATO     = :NRSEQCONTRATO
                   AND ITCONT.NRORG             = :NRORG
                   AND ITCONT.NRITEMCONTRATOPAI IS NULL
                   AND ITNEG.NRITEMCONTRATOPAI  IS NULL";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    /**
     * Update na tabela FCT_ITEMCONTRATO
    */
    public function atualizarValorItemContrato(array $params)
    {
        $sql = "UPDATE FCT_ITEMCONTRATO
                   SET VRUNITITEMCONT = ROUND(:VRUNITITEMCONT, 2),
                       VRTOTITEMCONT  = ROUND(:VRUNITITEMCONT * QTITEMCONTRATO * DECODE(NVL(QTMEDIDACONTR, 1), 0, 1, NVL(QTMEDIDACONTR, 1)), 2),
                       DTULTATU       = SYSDATE,
                       NRORGULTATU    = :NRORGULTATU,
                       CDOPERULTATU   = :CDOPERULTATU
                 WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO
                   AND NRORG           = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /**
     * Insert na tabela FCT_ITEMCONTRATO_HR
    */
    public function gerarHistoricoItemContrato($params)
    {
        $sql = "INSERT INTO FCT_ITEMCONTRATO_HR 
                    (NRCONTREAJUSTE, NRSEQCONTRATO, NRITEMOCONTRATO, IDREAJUSTE, VRPERCREAJUSTE, CDTPINDICE,
                     IDPERVALOR, CDINDICE, VRPERCINDICE, VRTOTITANT, VRTOTITNOVO, VRPERCVARIACAOIT,
                     NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO,NRULTIMOREAJUSTE)    
                VALUES
                    (:NRCONTREAJUSTE, :NRSEQCONTRATO, :NRITEMOCONTRATO, :IDREAJUSTE, :PERCENTUAL, :CDTPINDICE,
                     :IDPERVALOR, :CDINDICE, :PERCINDICE, ROUND(:VRTOTITEMCONT, 2), ROUND(:VRTOTAL, 2), :VRPERCVARIACAOIT,
                     :NRORG, SYSDATE, :NRORG, :CDOPERADOR, 'S', :NRULTIMOREAJUSTE)";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Update na tabela FCT_PARCELASNEGOCONT
    */
    public function reajustarParcelasNegociacao(array $params)
    {
        $sql = "UPDATE FCT_PARCELANEGOCONT
                   SET VRPARCELA = ROUND(VRPARCELA + (VRPARCELA * :VRPERCENTUAL / 100), 2),
                       DTULTATU       = SYSDATE,
                       NRORGULTATU    = :NRORGULTATU,
                       CDOPERULTATU   = :CDOPERULTATU
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getValorNegociacaoComSomaParcelas(array $params)
    {
        $sql = "SELECT NEG.NRNEGOCIACAOCONTRATO,
                       NEG.VRTOTITEMCOMDESC,
                       (SELECT SUM(VRPARCELA)
                          FROM FCT_PARCELANEGOCONT
                         WHERE NRNEGOCIACAOCONTRATO = NEG.NRNEGOCIACAOCONTRATO
                           AND NRORG                = NEG.NRORG) AS SOMA_PARCELAS
                  FROM FCT_NEGOCIACAOCONTRATO NEG
                 WHERE NEG.NRSEQCONTRATO        = :NRSEQCONTRATO
                   AND NEG.NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NEG.NRORG                = :NRORG
                   AND NEG.IDTPFATURA           = 'P'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    
    
    public function pegarDataAnteriorDoContrato(array $params)
    {
        $sql="SELECT C.DTINICIOCONTRATO,C.DTFIMCONTRATO, C.DTINIVIGENCONT, C.DTFINVIGENCONT 
               FROM FCT_CONTRATO C
               WHERE C.NRSEQCONTRATO = :NRSEQCONTRATO" ;
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getElementosContrato(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTELEMENTOS
                FROM FCT_TRABSERVCONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                  AND NRORG         = :NRORG
                  AND IDATIVO       = 'S'
                  AND IDESCOLHIDO   = 'S'";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    
    public function getIdBloqReajSemAliq(array $params)
    {
        $sql = "SELECT IDBLOQREAJSEMALIQ 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
                 
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getIndices(array $params)
    {
        $sql = "SELECT DISTINCT CDTPINDICE, IDPERVALOR, CDINDICE
                  FROM (
                    SELECT CDTPINDICE, IDPERVALOR, CDINDICE
                      FROM FCT_INDICESPADROES
                     WHERE NRORG = :NRORG
                     UNION ALL
                    SELECT CDTPINDICE, IDPERVALOR, CDINDICE
                      FROM FCT_INDICESPADRESCOPO
                     WHERE NRORG = :NRORG
                     UNION ALL
                    SELECT CDTPINDICE, IDPERVALOR, CDINDICE
                      FROM FCT_INDICESPADRPARC
                     WHERE NRORG = :NRORG
                     UNION ALL 
                    SELECT CDTPINDICE, IDPERVALOR, CDINDICE
                      FROM FCT_INDICESPADRCONTR
                     WHERE NRORG = :NRORG
                ) INDICES";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    
    public function getValidaIndicesCad(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTINDICES
                   FROM MOVINDICE
                  WHERE TRUNC(DTREFIND) BETWEEN ADD_MONTHS(FIRST_DAY(TRUNC(SYSDATE)), -12) AND ADD_MONTHS(LAST_DAY(TRUNC(SYSDATE)), -1)
                    AND CDTPINDICE = :CDTPINDICE
                    AND IDPERVALOR = :IDPERVALOR
                    AND CDINDICE = :CDINDICE
                    AND NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getValidaIndicesCadContrato(array $params)
    {
        $sql = "SELECT COUNT(*) AS QTINDICES
                   FROM MOVINDICE MOV, FCT_CONTRATO CONT
                  WHERE CONT.NRSEQCONTRATO = :NRSEQCONTRATO
                    AND TRUNC(MOV.DTREFIND) BETWEEN ADD_MONTHS(FIRST_DAY(TRUNC(ADD_MONTHS(NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO)+1, -1))), -11) AND LAST_DAY(TRUNC(ADD_MONTHS(NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO)+1, -1)))
                    AND MOV.CDTPINDICE = :CDTPINDICE
                    AND MOV.IDPERVALOR = :IDPERVALOR
                    AND MOV.CDINDICE = :CDINDICE
                    AND MOV.NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getIndicesContr(array $params)
    {
        $sql = "SELECT CDTPINDICE, IDPERVALOR, CDINDICE
                   FROM FCT_INDICESPADRCONTR
                  WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getIndicesEscopo(array $params)
    {
        $sql = "SELECT CDTPINDICE, IDPERVALOR, CDINDICE 
                   FROM FCT_INDICESPADRESCOPO   
                  WHERE NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                    AND NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    
    public function getIndicesParamSM(array $params)
    {
        $sql = "SELECT CDTPINDICE, IDPERVALOR, CDINDICE 
                   FROM FCT_INDICESPADROES   
                  WHERE NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function validaPercIndicesContr(array $params)
    {
        $sql = "SELECT SUM(NRPERCENTINDICE) AS PERCENTUAL
                   FROM FCT_INDICESPADRCONTR
                  WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function validaPercIndicesEscopo(array $params)
    {
        $sql = "SELECT SUM(NRPERCENTINDICE) AS PERCENTUAL
                   FROM FCT_INDICESPADRESCOPO   
                  WHERE NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                    AND NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function validaPercIndicesParamSM(array $params)
    {
        $sql = "SELECT SUM(NRPERCENTINDICE) AS PERCENTUAL 
                   FROM FCT_INDICESPADROES   
                  WHERE NRORG = :NRORG";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /* recebe os itens do contrato */
    public function getitensContrato(array $params)
    {
        $sql = "SELECT ITCONT.NRITEMOCONTRATO, ITCONT.NRSEQCONTRATO, ITCONT.NMITEMCONTRATO, ITCONT.QTITEMCONTRATO, 
                          ITCONT.QTMEDIDACONTR, ITCONT.VRUNITITEMCONT, ITNEG.NRITNEGOCIACAOCONTRATO,ITNEG.NRNEGOCIACAOCONTRATO
                     FROM FCT_ITEMCONTRATO ITCONT
                     LEFT JOIN FCT_ITNEGOCIACAOCONTRATO ITNEG
                       ON ITCONT.NRITEMOCONTRATO = ITNEG.NRITEMOCONTRATO
                      AND ITCONT.NRORG           = ITNEG.NRORG
                    WHERE ITCONT.NRSEQCONTRATO = :NRSEQCONTRATO
                      AND ITCONT.NRORG         = :NRORG
                      AND ITCONT.IDELEMENTO IS NULL";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /* Recebe os itens filhos dos itens do contrato */
    public function getitensFilhosItContrato(array $params)
    {
        $sql = "SELECT ITCONT.NRITEMOCONTRATO, ITCONT.NRSEQCONTRATO, ITCONT.NMITEMCONTRATO, ITCONT.QTITEMCONTRATO, 
                          ITCONT.QTMEDIDACONTR, ITCONT.VRUNITITEMCONT, ITCONT.VRTOTITEMCONT, ITNEG.NRITNEGOCIACAOCONTRATO,ITNEG.NRNEGOCIACAOCONTRATO
                     FROM FCT_ITEMCONTRATO ITCONT
                     LEFT JOIN FCT_ITNEGOCIACAOCONTRATO ITNEG
                       ON ITCONT.NRITEMOCONTRATO = ITNEG.NRITEMOCONTRATO
                      AND ITCONT.NRORG           = ITNEG.NRORG
                    WHERE ITCONT.NRSEQCONTRATO     = :NRSEQCONTRATO
                      AND ITCONT.NRORG             = :NRORG
                      AND ITCONT.NRITEMCONTRATOPAI = :NRITEMOCONTRATO
                      AND ITCONT.IDADICITEMCONT    = 'N'";
                     
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /* Atualiza os itens do contrato */
    public function updateItens(array $params)
    {
        $sql = "UPDATE FCT_ITEMCONTRATO
                   SET VRUNITITEMCONT = :VRUNITITEMCONT,
                       VRTOTITEMCONT = :VRTOTITEMCONT,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO
                   AND NRORG = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function inserirHistoricoItemContrato($params)
    {
        $sql = "INSERT INTO FCT_ITEMCONTRATO_HR(
					NRITEMCONTRATO_HR,NRITEMOCONTRATO,QTITEMCONTRATO
					,QTMEDIDACONTR,VRUNITITEMCONT,VRTOTITEMCONT,NRORG,IDATIVO
					,CDOPERINCLUSAO,IDMULTMEDVRTOT,VRUNITITEMCONTTBLPRECO,
					QTMEDIDACALCULADA,NRULTIMOREAJUSTE
				)
				SELECT
					:NRITEMCONTRATO_HR,NRITEMOCONTRATO,ROUND(QTITEMCONTRATO,2),
					ROUND(QTMEDIDACONTR,2),VRUNITITEMCONT,ROUND(VRTOTITEMCONT, 2),NRORG,
					IDATIVO,:CDOPERINCLUSAO,IDMULTMEDVRTOT,VRUNITITEMCONTTBLPRECO,
					ROUND(QTMEDIDACALCULADA, 2),:NRULTIMOREAJUSTE 
				FROM FCT_ITEMCONTRATO
				WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function inserirHistoricoItensNegociacao($params)
    {
        $sql = "INSERT INTO FCT_ITNEGOCIACAOCONTRATO_HR(
    		    NRITNEGOCIACAOCONTRATO_HR ,NRITNEGOCIACAOCONTRATO,NRNEGOCIACAOCONTRATO,
    		    NRITEMOCONTRATO,VRTOTITEM,VRPERCDESCITEM,
    		    VRDESCITEM,VRTOTITEMCOMDESC,IDATIVO,NRORG,
    		    CDOPERINCLUSAO,NRITEMCONTRATOPAI,IDTPDESCONTO,NRULTIMOREAJUSTE
			)
			SELECT 
    			:NRITNEGOCIACAOCONTRATO_HR ,NRITNEGOCIACAOCONTRATO,NRNEGOCIACAOCONTRATO,
    			NRITEMOCONTRATO,ROUND(VRTOTITEM,2),ROUND(VRPERCDESCITEM,2),
    			ROUND(VRDESCITEM,2),ROUND(VRTOTITEMCOMDESC,2),IDATIVO,NRORG,
    			:CDOPERINCLUSAO,NRITEMCONTRATOPAI,IDTPDESCONTO,:NRULTIMOREAJUSTE
			FROM FCT_ITNEGOCIACAOCONTRATO
    		WHERE NRITNEGOCIACAOCONTRATO = :NRITNEGOCIACAOCONTRATO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function inserirNegociacaoDeValoresHistoricoReajuste($params)
    {
        $sql = "INSERT INTO FCT_NEGOCIACAOCONTRATO_HR(
			NRNEGOCIACAOCONTRATO_HR, NRNEGOCIACAOCONTRATO, 
			VRTOTITEM, VRPERCDESCITEM, VRDESCITEM,VRTOTITEMCOMDESC, 
			IDATIVO, NRORG, CDOPERINCLUSAO,IDTPDESCONTO,NRULTIMOREAJUSTE
		)
		SELECT
		    :NRNEGOCIACAOCONTRATO_HR,NRNEGOCIACAOCONTRATO,
			ROUND(VRTOTITEM,2),VRPERCDESCITEM,ROUND(VRDESCITEM,2),ROUND(VRTOTITEMCOMDESC,2),IDATIVO,
			NRORG,:CDOPERINCLUSAO,IDTPDESCONTO,:NRULTIMOREAJUSTE
		FROM FCT_NEGOCIACAOCONTRATO
		WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function inserirHistoricoParcelaNegoContrato($params)
    {
        $sql = "INSERT INTO FCT_PARCELANEGOCONT_HR(
			NRPARCELANEGOCONT_HR,NRPARCELANEGOCONT,NRNEGOCIACAOCONTRATO,VRPARCELA,
			IDATIVO,NRORG,CDOPERINCLUSAO,NRPARCELA,NRULTIMOREAJUSTE)
			VALUES(
			:NRPARCELANEGOCONT_HR,:NRPARCELANEGOCONT,:NRNEGOCIACAOCONTRATO,ROUND(:VRPARCELA,2),
			:IDATIVO,:NRORG,:CDOPERINCLUSAO,:NRPARCELA,:NRULTIMOREAJUSTE)";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getParcelasDaNegociacao(array $params)
    {
        $sql = "SELECT  
                    NRPARCELANEGOCONT,NRNEGOCIACAOCONTRATO,VRPARCELA,
			        IDATIVO,NRORG,CDOPERINCLUSAO,NRPARCELA
                  FROM FCT_PARCELANEGOCONT
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    //#region REAJUSTE AUTOMATICO DO CONTRATO
    /**
     * Função responsável por pegar os parametros necessários para reajustar automaticamente os contratos de uma organização
     *
     * @param [string] $nrorg - Organização em questão
     * @return array() - todos os dados relevantes do reajuste de uma organização
     */
    public function getParametrosGeracaoRelatorio($nrorg)
    {
        //TODO - Encontrar o similar a esse DSEMAIL porem relacionado ao reajuste
        $sql = "SELECT DSEMAILALERTRENOVCONT,
                       IDPERIODALERTRENOVCONT
                FROM FCT_PARAMETROGERAL
                WHERE NRORG = $nrorg";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    /**
     * Função responsável por pegar todos os números dos contratos a serem reajustados automaticamente dentro de uma organização
     *
     * @param [array()] $params - parametros da consulta
     * @return array()- array associativo contendo todos os contratos que precisam de ser reajustados
     */
    public function getContratosASeremReajustadosAutomaticamente(array $params)
    {
        $sql="SELECT NRSEQCONTRATO 
                FROM FCT_CONTRATO
               WHERE NRORG = :NRORG
                 AND TRUNC(DTPADREAJCONT) <= TRUNC(TO_DATE(:DTPADREAJCONT, 'DD/MM/YYYY'))
                 AND IDREAJUSTEAUTOMATICO = :IDREAJUSTEAUTOMATICO
                 AND IDSITUACAOCONTRATO = 'A'";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Função responsável por pegar todos os contratos a serem reajustados automaticamente dentro de uma organização
     *
     * @param [array()] $params - parametros da consulta
     * @return array()- array associativo contendo todos os contratos que precisam de ser reajustados
     */
    public function getContratosReajustadosAutomaticamente(array $params)
    {
        $sql="SELECT TBL.NRSEQCONTRATO,
                     TBL.NRCONTRATOFCT,
                     TBL.NRPARCNEGOCIO,
                     TBL.NMPRINCIPALPARC,
                     TBL.CDTPINDICE,
                     TBL.IDPERVALOR,
                     TBL.CDINDICE,
                     TBL.NMINDICE,
                     TBL.NRPERCENTINDICE,
                     TBL.VRINDICE,
                     TBL.NRORG,
                     TBL.DTINCLUSAO,
                     CONT.DTPADREAJCONT,
                     TO_CHAR(NVL(CONT.DTINIVIGENCONT, CONT.DTINICIOCONTRATO), 'DD/MM/YYYY') AS DTINIVIGENCONT,
                     TO_CHAR(NVL(CONT.DTFINVIGENCONT, CONT.DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFINVIGENCONT
                FROM TABLE(FCT_BUSCA_INDICEREAJUSTE(:NRSEQCONTRATO, :NRORG)) TBL
               INNER JOIN FCT_CONTRATO CONT
                  ON TBL.NRSEQCONTRATO = CONT.NRSEQCONTRATO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    /**
     * Procedimento responsável por inserir Log relacionados ao reajuste do contrato
     *
     * @param [array()] $params - parametros da consulta
     * @return void
     */
    public function inserirLogReajusteContrato($params)
    {
        $sql="INSERT INTO FCT_LOGREAJUSTECONTRATO
                   ( NRSEQCONTRATO, DSERRO, VRPERCREAJUSTE, CDTPINDICE, IDPERVALOR, CDINDICE, 
                   VRCONTRATO, NRORG, DTINCLUSAO, DTPRXREAJ, DTANTREAJ, VRNVCONTRATO )
                   VALUES (:NRSEQCONTRATO,:DSERRO, ROUND(:VRPERCREAJUSTE,2), :CDTPINDICE, :IDPERVALOR, :CDINDICE, 
                   ROUND(:VRCONTRATO,2), :NRORG, TRUNC(SYSDATE), :DTPRXREAJ, :DTANTREAJ, ROUND(:VRNVCONTRATO,2))";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    /**
     * Procedimento responsável por excluir todos os logs do reajuste do contrato
     *
     * @param [array()] $params - parametros da consulta
     * @return void
     */
    public function deletarLogErroReajusteContrato($params)
    {
        $sql="DELETE 
               FROM FCT_LOGREAJUSTECONTRATO
               WHERE NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Função responsável por pegar os números de uma fatura baseada no contrato de uma organização
     *
     * @param array $params = [
     *                              "NRSEQCONTRATO" => (NUMBER) número do contrato a ser consultado
     *                          ]
     * @return array = [
     *                              "NUMEROMEDICAOFATURA" => (NUMBER) PK da tabela FCT_NUMEROMEDICAOFATURA
     *                          ]
     */
    public function getNumeroMedicaoContrato(array $params)
    {
        $sql="SELECT NRMEDICAOFATURA 
                FROM FCT_MEDICAOFATURA
               WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                 AND IDSITUACAO = '3'
                 AND TRUNC(DTINICOMPET) BETWEEN TRUNC(TO_DATE(:DTINICOMPET, 'DD/MM/YYYY')) AND TRUNC(TO_DATE(:DTFINCOMPET, 'DD/MM/YYYY'))
                 AND TRUNC(DTFINCOMPET) BETWEEN TRUNC(TO_DATE(:DTINICOMPET, 'DD/MM/YYYY')) AND TRUNC(TO_DATE(:DTFINCOMPET, 'DD/MM/YYYY'))";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getValoreReajusteContrato(array $params)
    {
        $sql="SELECT VRPERCREAJUSTE
                   FROM FCT_CONTRATOREAJUSTE
                   WHERE NRSEQCONTRATO = :NRSEQCONTRATO ";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getDadosReajusteContratoLog(array $params)
    {
        $sql="SELECT (DTPADREAJCONT + NVL(NRDIASREAJAUTOMATICO, 365)) AS DTPADREAJCONT,
                     (SELECT SUM(VRTOTITEMCOMDESC) 
					    FROM FCT_NEGOCIACAOCONTRATO 
					   WHERE NRSEQCONTRATO = :NRSEQCONTRATO) AS VRCONTRATO
			    FROM FCT_CONTRATO 
			   WHERE NRSEQCONTRATO = :NRSEQCONTRATO";
		
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function getValorContrato(array $params)
    {
        $sql="SELECT NVL(SUM(VRTOTITEMCOMDESC), 0) AS VRCONTRATO
			  FROM FCT_NEGOCIACAOCONTRATO 
			  WHERE NRSEQCONTRATO = :NRSEQCONTRATO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function atualizarDataPadraoDeReajuste(array $params){
        $sql="UPDATE FCT_CONTRATO
              SET DTPADREAJCONT = :DTPADREAJCONT
              WHERE NRSEQCONTRATO = :NRSEQCONTRATO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizarDataPadraoDeReajusteEDia(array $params){
        $sql="UPDATE FCT_CONTRATO
              SET DTPADREAJCONT = :DTPADREAJCONT,
                  NRDIASREAJAUTOMATICO = :NRDIASREAJAUTOMATICO
              WHERE NRSEQCONTRATO = :NRSEQCONTRATO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    //#endregion
}
