<?php
namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00029000LocalAtendimentoFactory
{
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * A função "verificaTipoHierarqOrg" Verifica se existe o tipo de Hierarquia Padrão.
     */
     
    public function verificaTipoHierarqOrg($params){
        
        $sql = "SELECT NRTIPOHIERARQORG
                  FROM TIPOHIERARQORG
                 WHERE NMTIPOHIERARQORG = 'Padrão - Local de Atendimento SM'
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Salva o Tipo de Hierarquia.
     */
     
    public function inserirTipoHierarquiaOrg($params){
        
        $sql = "INSERT INTO TIPOHIERARQORG (
                    NRTIPOHIERARQORG, NMTIPOHIERARQORG, NRTIPOESTRUTSUP, NRTIPOESTRUTREL, 
                    NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO
                )
                VALUES (
                    :NRTIPOHIERARQORG, :NMTIPOHIERARQORG, :NRTIPOESTRUTSUP, :NRTIPOESTRUTREL, 
                    :NRORG, :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO
                )";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Salva o Parceiro de Negócio.
     */
    public function inserirParcNegocio($params){
        
        $sql = "INSERT INTO PARCNEGOCIO (
                    NRPARCNEGOCIO, NMPRINCIPALPARC, NMSECUNDARIPARC, NRINSCRICAOPARC, CDTIPOPARCPRINCIPAL,
                    CDTIPOINSCRICAO, IDPESSOAFISICA, IDINSTITUICAO, IDPARCFUNDIDO, NRORG, DTINCLUSAO, NRORGINCLUSAO,
                    CDOPERINCLUSAO, IDATIVO
                )
                VALUES(
                    :NRPARCNEGOCIO, :NMPRINCIPALPARC, :NMSECUNDARIPARC, :NRINSCRICAOPARC, :CDTIPOPARCPRINCIPAL, 
                    NVL(:CDTIPOINSCRICAO,'LIVRE'), :IDPESSOAFISICA, :IDINSTITUICAO, :IDPARCFUNDIDO, :NRORG, :DTINCLUSAO, 
                    :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO
                )";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
  
     /**
     * Atualiza o Parceiro de Negócio.
     */
    public function editarParcNegocio($params){
        
        $sql = "UPDATE PARCNEGOCIO
                SET NMPRINCIPALPARC     = :NMPRINCIPALPARC,
                    NMSECUNDARIPARC     = :NMSECUNDARIPARC,
                    NRINSCRICAOPARC     = :NRINSCRICAOPARC,
                    CDTIPOINSCRICAO     = :CDTIPOINSCRICAO,
                    CDOPERULTATU        = :CDOPERULTATU,
                    DTULTATU            = SYSDATE,
                    NRORGULTATU         = :NRORG
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                  AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
  
   /**
     * Deleta o Parceiro de Negócio.
     */
    public function deletarParcNegocio($params){
        
        $sql = "DELETE FROM PARCNEGOCIO
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG = :NRORG ";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
  
    /**
     * Salva a Estrutura M.
     */
    public function inserirEstruturaM($params){
        
        $sql = "INSERT INTO ESTRUTURAM (
                    NRESTRUTURAM, NMESTRUTURAM, NRTIPOESTRUTURA, DTINIVIGENCIA, NRPARCNEGOCIO,
                    CDCENTCUST, NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO
                )
                VALUES (
                    :NRESTRUTURAM, :NMESTRUTURAM, :NRTIPOESTRUTURA, :DTINIVIGENCIA, :NRPARCNEGOCIO, 
                    :CDCENTCUST, :NRORG, :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO
                )";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Atualiza a Estrutura M.
     */
    public function editarEstruturaM($params){
        
        $sql = "UPDATE ESTRUTURAM
                SET NMESTRUTURAM    = :NMESTRUTURAM,
                    NRTIPOESTRUTURA = :NRTIPOESTRUTURA,
                    CDCENTCUST      = :CDCENTCUST,
                    CDOPERULTATU    = :CDOPERULTATU,
                    DTULTATU        = SYSDATE,
                    NRORGULTATU     = :NRORG
                WHERE NRESTRUTURAM = :NRESTRUTURAM
                 AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Deleta a Estrutura M.
     */
    public function deletarEstruturaM($params){
        
        $sql = "DELETE FROM ESTRUTURAM
                 WHERE NRESTRUTURAM = :NRESTRUTURAM
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
   
    /**
     * Salva a Estrutura H.
     */
    public function inserirEstruturaH($params){
        
        $sql = "INSERT INTO ESTRUTURAH (
                    NRESTRUTURAH, NMESTRUTURAH, NRESTRUTURAM, DTMESCOMPETENC, NRPARCNEGOCIO,
                    NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO
                )
                VALUES (
                    :NRESTRUTURAH, :NMESTRUTURAH, :NRESTRUTURAM, :DTMESCOMPETENC, :NRPARCNEGOCIO,
                    :NRORG, :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO
                )";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Atualiza a Estrutura H.
     */
    public function editarEstruturaH($params){
        
        $sql = "UPDATE ESTRUTURAH
                SET NMESTRUTURAH = :NMESTRUTURAM,
                    CDOPERULTATU = :CDOPERULTATU,
                    DTULTATU     = SYSDATE,
                    NRORGULTATU  = :NRORG
                WHERE NRESTRUTURAH = :NRESTRUTURAH
                  AND NRESTRUTURAM = :NRESTRUTURAM
                  AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Deleta a Estrutura H.
     */
    public function deletarEstruturaH($params){
        
        $sql = "DELETE FROM ESTRUTURAH
                 WHERE NRESTRUTURAM = :NRESTRUTURAM
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
     /**
     * Salva a Hierarquia da Estrutura.
     */
    public function inserirHierarquiaOrg($params){
        
        $sql = "INSERT INTO HIERARQUIAORG (
                    NRHIERARQUIAORG, NRTIPOHIERARQORG, NRESTRUTURAMSUP, NRESTRUTURAMREL, DTINIVIGENCIA, 
                    NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO
                )
                VALUES (
                    :NRHIERARQUIAORG, :NRTIPOHIERARQORG, :NRESTRUTURAMSUP, :NRESTRUTURAMREL, :DTINIVIGENCIA,
                    :NRORG, :DTINCLUSAO, :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO
                )";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
     /**
     * Atualiza a Hierarquia da Estrutura.
     */
    public function editarHierarquiaOrg($params){
        
        $sql = "UPDATE HIERARQUIAORG
                SET NRESTRUTURAMSUP = :NRESTRUTURAMSUP,
                    NRESTRUTURAMREL = :NRESTRUTURAMREL,
                    CDOPERULTATU    = :CDOPERULTATU,
                    DTULTATU        = SYSDATE,
                    NRORGULTATU     = :NRORG
                WHERE NRHIERARQUIAORG = :NRHIERARQUIAORG
                  AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Deleta a Hierarquia da Estrutura.
     */
    public function deletarHierarquiaOrg($params){

        $sql = "DELETE FROM HIERARQUIAORG 
                 WHERE ((NRESTRUTURAMREL = :NRESTRUTURAM) 
                    OR (NRESTRUTURAMSUP = :NRESTRUTURAM))
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Salva o endereço de Hierarquia da Estrutura.
     */
    public function inserirEnderecoParc($params){
        
        $sql = "INSERT INTO ENDERECOPARC (
                    NRENDERECOPARC, NRPARCNEGOCIO, CDTIPOENDERECO, DSENDERECO, NRIMOVELENDERECO,
                    DSCOMPLEENDERECO, CDPAIS, SGESTADO, CDMUNICIPIO, CDBAIRRO, 
                    NMBAIRROENDERECO, NRCEPENDERECO, DSREFERENCIAENDE, NRORG, DTINCLUSAO, 
                    NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO
                )
                VALUES(
                    :NRENDERECOPARC, :NRPARCNEGOCIO, :CDTIPOENDERECO, :DSENDERECO, :NRIMOVELENDERECO,
                    :DSCOMPLEENDERECO, :CDPAIS, :SGESTADO, :CDMUNICIPIO, :CDBAIRRO, 
                    :NMBAIRROENDERECO, :NRCEPENDERECO, :DSREFERENCIAENDE, :NRORG, :DTINCLUSAO, 
                    :NRORGINCLUSAO, :CDOPERINCLUSAO, :IDATIVO
                )";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Atualiza o endereço de Hierarquia da Estrutura.
     */
    public function editarEnderecoParc($params){
        
        $sql = "UPDATE ENDERECOPARC
                   SET DSENDERECO       = :DSENDERECO,
                       NRIMOVELENDERECO = :NRIMOVELENDERECO,
                       DSCOMPLEENDERECO = :DSCOMPLEENDERECO,
                       CDPAIS           = :CDPAIS,                    
                       SGESTADO         = :SGESTADO,                
                       CDMUNICIPIO      = :CDMUNICIPIO,          
                       CDBAIRRO         = :CDBAIRRO,                
                       NMBAIRROENDERECO = :NMBAIRROENDERECO,
                       NRCEPENDERECO    = :NRCEPENDERECO,      
                       DSREFERENCIAENDE = :DSREFERENCIAENDE,
                       CDOPERULTATU     = :CDOPERULTATU,        
                       DTULTATU         = SYSDATE,                  
                       NRORGULTATU      = :NRORG                 
                 WHERE NRENDERECOPARC   = :NRENDERECOPARC
                   AND NRPARCNEGOCIO    = :NRPARCNEGOCIO
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
     /**
     * Deleta o endereço de Hierarquia da Estrutura.
     */
    public function deletarEnderecoParc($params){
        
        $sql = "DELETE FROM ENDERECOPARC
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     *  Recebe as hierarquias filhas para que sejam deletadas junto com o pai.
    */
    public function recebefilhos($params){
        $sql = "SELECT LEVEL, ESTRUTURAM.NRESTRUTURAM, ESTRUTURAM.NRPARCNEGOCIO
                  FROM HIERARQUIAORG 
                  LEFT JOIN ESTRUTURAM
                    ON HIERARQUIAORG.NRESTRUTURAMREL = ESTRUTURAM.NRESTRUTURAM
                   AND HIERARQUIAORG.NRORG = ESTRUTURAM.NRORG 
                 WHERE HIERARQUIAORG.NRORG  = :NRORG
                 START WITH HIERARQUIAORG.NRESTRUTURAMREL  = :NRESTRUTURAM
                CONNECT BY PRIOR HIERARQUIAORG.NRESTRUTURAMREL = HIERARQUIAORG.NRESTRUTURAMSUP
                ORDER BY LEVEL DESC";
     
         $std = $this->connection->prepare($sql);
         $std->execute($params);
         return $std->fetchAll(); 
    } 
}
?>